==> jc-1.4.0.tar.gz: soot/dava/internal/javaRep/DInstanceFieldRef.h <==
// public class soot.dava.internal.javaRep.DInstanceFieldRef

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class df053b3668c45918 soot_dava_internal_javaRep_DInstanceFieldRef
// @dep_class ab8ec73b8644c0c6 soot_grimp_internal_GInstanceFieldRef
// @dep_class 2166ff1c3b2462a3 soot_jimple_internal_AbstractInstanceFieldRef

// header file dependencies
// @dep_header soot_grimp_internal_GInstanceFieldRef

#include "soot/grimp/internal/GInstanceFieldRef.h"

#ifndef _JC_soot_dava_internal_javaRep_DInstanceFieldRef_H_
#define _JC_soot_dava_internal_javaRep_DInstanceFieldRef_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_HashSet$object;
struct _jc_soot_SootField$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$sub_refs	_jc_soot_dava_internal_javaRep_DInstanceFieldRef$sub_refs;
typedef struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$sub_nonrefs	_jc_soot_dava_internal_javaRep_DInstanceFieldRef$sub_nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$refs	_jc_soot_dava_internal_javaRep_DInstanceFieldRef$refs;
typedef struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$nonrefs	_jc_soot_dava_internal_javaRep_DInstanceFieldRef$nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$object	_jc_soot_dava_internal_javaRep_DInstanceFieldRef$object;

typedef const struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$vmethods	_jc_soot_dava_internal_javaRep_DInstanceFieldRef$vmethods;
typedef const struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$vtable	_jc_soot_dava_internal_javaRep_DInstanceFieldRef$vtable;
typedef const struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$vtype	_jc_soot_dava_internal_javaRep_DInstanceFieldRef$vtype;

// Constructors
extern void _jc_soot_dava_internal_javaRep_DInstanceFieldRef$method$_init$35c39f0686d14c9d(_jc_env *, struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$object *, struct _jc_object *, struct _jc_soot_SootField$object *, struct _jc_java_util_HashSet$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_dava_internal_javaRep_DInstanceFieldRef$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$object *);
extern struct _jc_java_lang_String$object *_jc_soot_dava_internal_javaRep_DInstanceFieldRef$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$object *);
extern void _jc_soot_dava_internal_javaRep_DInstanceFieldRef$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_javaRep_DInstanceFieldRef$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_dava_internal_javaRep_DInstanceFieldRef$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_dava_internal_javaRep_DInstanceFieldRef$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$object *);
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractInstanceFieldRef$vmethods	soot_jimple_internal_AbstractInstanceFieldRef;
	_jc_soot_grimp_internal_GInstanceFieldRef$vmethods	soot_grimp_internal_GInstanceFieldRef;
	_jc_soot_dava_internal_javaRep_DInstanceFieldRef$vmethods	soot_dava_internal_javaRep_DInstanceFieldRef;
};

// Vtype
struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_javaRep_DInstanceFieldRef$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$sub_refs {
	struct _jc_java_util_HashSet$object	*thisLocals;
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$refs {
    _jc_soot_dava_internal_javaRep_DInstanceFieldRef$sub_refs	soot_dava_internal_javaRep_DInstanceFieldRef;
    _jc_soot_grimp_internal_GInstanceFieldRef$sub_refs	soot_grimp_internal_GInstanceFieldRef;
    _jc_soot_jimple_internal_AbstractInstanceFieldRef$sub_refs	soot_jimple_internal_AbstractInstanceFieldRef;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractInstanceFieldRef$sub_nonrefs	soot_jimple_internal_AbstractInstanceFieldRef;
    _jc_soot_grimp_internal_GInstanceFieldRef$sub_nonrefs	soot_grimp_internal_GInstanceFieldRef;
    _jc_soot_dava_internal_javaRep_DInstanceFieldRef$sub_nonrefs	soot_dava_internal_javaRep_DInstanceFieldRef;
};

// Object instance structure
struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$object {
	_jc_soot_dava_internal_javaRep_DInstanceFieldRef$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_javaRep_DInstanceFieldRef$vtype	*vtype;
	_jc_soot_dava_internal_javaRep_DInstanceFieldRef$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_javaRep_DInstanceFieldRef$vtype _jc_soot_dava_internal_javaRep_DInstanceFieldRef$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_javaRep_DInstanceFieldRef, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_javaRep_DInstanceFieldRef$class_object;

#endif	/* _JC_soot_dava_internal_javaRep_DInstanceFieldRef_H_ */

==> jc-1.4.6.tar.gz: soot/dava/internal/javaRep/DInstanceFieldRef.h <==
// public class soot.dava.internal.javaRep.DInstanceFieldRef

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class df053b3668c45918 soot_dava_internal_javaRep_DInstanceFieldRef
// @dep_class ab8ec73b8644c0c6 soot_grimp_internal_GInstanceFieldRef
// @dep_class 2166ff1c3b2462a3 soot_jimple_internal_AbstractInstanceFieldRef

// header file dependencies
// @dep_header soot_grimp_internal_GInstanceFieldRef

#include "soot/grimp/internal/GInstanceFieldRef.h"

#ifndef _JC_soot_dava_internal_javaRep_DInstanceFieldRef_H_
#define _JC_soot_dava_internal_javaRep_DInstanceFieldRef_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_HashSet$object;
struct _jc_soot_SootField$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$sub_refs	_jc_soot_dava_internal_javaRep_DInstanceFieldRef$sub_refs;
typedef struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$sub_nonrefs	_jc_soot_dava_internal_javaRep_DInstanceFieldRef$sub_nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$refs	_jc_soot_dava_internal_javaRep_DInstanceFieldRef$refs;
typedef struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$nonrefs	_jc_soot_dava_internal_javaRep_DInstanceFieldRef$nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$object	_jc_soot_dava_internal_javaRep_DInstanceFieldRef$object;

typedef const struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$vmethods	_jc_soot_dava_internal_javaRep_DInstanceFieldRef$vmethods;
typedef const struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$vtable	_jc_soot_dava_internal_javaRep_DInstanceFieldRef$vtable;
typedef const struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$vtype	_jc_soot_dava_internal_javaRep_DInstanceFieldRef$vtype;

// Constructors
extern void _jc_soot_dava_internal_javaRep_DInstanceFieldRef$method$_init$35c39f0686d14c9d(_jc_env *, struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$object *, struct _jc_object *, struct _jc_soot_SootField$object *, struct _jc_java_util_HashSet$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_dava_internal_javaRep_DInstanceFieldRef$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_dava_internal_javaRep_DInstanceFieldRef$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_internal_javaRep_DInstanceFieldRef$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_javaRep_DInstanceFieldRef$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_dava_internal_javaRep_DInstanceFieldRef$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_dava_internal_javaRep_DInstanceFieldRef$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$object *) _JC_JCNI_ATTR;
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractInstanceFieldRef$vmethods	soot_jimple_internal_AbstractInstanceFieldRef;
	_jc_soot_grimp_internal_GInstanceFieldRef$vmethods	soot_grimp_internal_GInstanceFieldRef;
	_jc_soot_dava_internal_javaRep_DInstanceFieldRef$vmethods	soot_dava_internal_javaRep_DInstanceFieldRef;
};

// Vtype
struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_javaRep_DInstanceFieldRef$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$sub_refs {
	struct _jc_java_util_HashSet$object	*thisLocals;
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$refs {
    _jc_soot_dava_internal_javaRep_DInstanceFieldRef$sub_refs	soot_dava_internal_javaRep_DInstanceFieldRef;
    _jc_soot_grimp_internal_GInstanceFieldRef$sub_refs	soot_grimp_internal_GInstanceFieldRef;
    _jc_soot_jimple_internal_AbstractInstanceFieldRef$sub_refs	soot_jimple_internal_AbstractInstanceFieldRef;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractInstanceFieldRef$sub_nonrefs	soot_jimple_internal_AbstractInstanceFieldRef;
    _jc_soot_grimp_internal_GInstanceFieldRef$sub_nonrefs	soot_grimp_internal_GInstanceFieldRef;
    _jc_soot_dava_internal_javaRep_DInstanceFieldRef$sub_nonrefs	soot_dava_internal_javaRep_DInstanceFieldRef;
};

// Object instance structure
struct _jc_soot_dava_internal_javaRep_DInstanceFieldRef$object {
	_jc_soot_dava_internal_javaRep_DInstanceFieldRef$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_javaRep_DInstanceFieldRef$vtype	*vtype;
	_jc_soot_dava_internal_javaRep_DInstanceFieldRef$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_javaRep_DInstanceFieldRef$vtype _jc_soot_dava_internal_javaRep_DInstanceFieldRef$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_javaRep_DInstanceFieldRef, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_javaRep_DInstanceFieldRef$class_object;

#endif	/* _JC_soot_dava_internal_javaRep_DInstanceFieldRef_H_ */
